@@ -1,5 +1,17 @@
 var NAVTREEINDEX21 =
 {
+"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[10,8,7,23,3],
+"structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[10,8,7,23,1],
+"structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[10,8,7,23,4],
+"structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[10,8,7,23,2],
+"structspa__audio__layout__info.html":[10,8,7,22],
+"structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[10,8,7,22,1],
+"structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[10,8,7,22,0],
+"structspa__buffer.html":[10,8,1,7],
+"structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[10,8,1,7,0],
+"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[10,8,1,7,2],
+"structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560":[10,8,1,7,3],
+"structspa__buffer.html#adbf5510ef0707e22b19980c84b61a073":[10,8,1,7,1],
 "structspa__buffer__alloc__info.html":[10,8,1,4],
 "structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6":[10,8,1,4,11],
 "structspa__buffer__alloc__info.html#a30233569ad362f458d9e1344d0b5a58c":[10,8,1,4,10],
@@ -237,17 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__io__segment__video.html#ae03652e1ab2e76a1a03a63d7bd0fcc99":[10,8,6,14,8],
 "structspa__io__segment__video.html#ae1cc1d15b524665254cff4c3d5daeceb":[10,8,6,14,6],
 "structspa__io__segment__video.html#aefffdac704f6aa878542c37d5cc7accb":[10,8,6,14,1],
-"structspa__io__sequence.html":[10,8,6,12],
-"structspa__io__sequence.html#ab6a424dad012da97efc02bfa77ed57d9":[10,8,6,12,0],
-"structspa__io__video__size.html":[10,8,6,10],
-"structspa__io__video__size.html#a14c82d8b6ae358c42c68f7dba2666b18":[10,8,6,10,3],
-"structspa__io__video__size.html#a259e1fe5e8894a35cf6849b94059ac7f":[10,8,6,10,4],
-"structspa__io__video__size.html#a817931821ee7f154884141faa47647c0":[10,8,6,10,1],
-"structspa__io__video__size.html#ab8f1361af870dd5de789b63b687a22ce":[10,8,6,10,0],
-"structspa__io__video__size.html#ac21892f7b4b6c90063b80306659a657b":[10,8,6,10,2],
-"structspa__json.html":[10,8,8,6,1],
-"structspa__json.html#a0d67dd0c9901c7b451b224b4102e20fd":[10,8,8,6,1,4],
-"structspa__json.html#a60cdc9944f16c66d15eace2d674d7e04":[10,8,8,6,1,0],
-"structspa__json.html#a8a0962e6aafa40f4b0124bcbb94e04df":[10,8,8,6,1,3],
-"structspa__json.html#a8c09dbf1f541a944ceef31cb0b4110af":[10,8,8,6,1,1]
+"structspa__io__sequence.html":[10,8,6,12]
 };
