@@ -1,5 +1,36 @@
 var NAVTREEINDEX6 =
 {
+"group__pw__permission.html#ga77df16320c3bb338666f55b2b21e6e47":[10,4,11,6],
+"group__pw__permission.html#ga97d33a5e044ee126fd9991b8c70424aa":[10,4,11,3],
+"group__pw__permission.html#ga9f4fda4d9b16f0595986e2d63265fb63":[10,4,11,7],
+"group__pw__permission.html#gaa61804de7cf6003defd8b26ef488ce56":[10,4,11,9],
+"group__pw__permission.html#gaa6b729cf828ec6417f5ba997560fda2b":[10,4,11,14],
+"group__pw__permission.html#gab3c2f31e9ed5b2578d2d86b32a3b7103":[10,4,11,12],
+"group__pw__permission.html#gadea4630c0fbf61f2c42de3339c81abe2":[10,4,11,11],
+"group__pw__permission.html#gaff0a46d4bd012b8d421e848637d64f30":[10,4,11,16],
+"group__pw__pipewire.html":[10,4,0],
+"group__pw__pipewire.html#ga06c879b2d800579f4724109054368d99":[10,4,0,1],
+"group__pw__pipewire.html#ga0a42d8f153fc58df733f74e5bf9af251":[10,4,0,14],
+"group__pw__pipewire.html#ga1bffd3e2e02f201486d7d9f17950e5eb":[10,4,0,5],
+"group__pw__pipewire.html#ga245d94286ccbb5c23cec4448cc7070f0":[10,4,0,9],
+"group__pw__pipewire.html#ga4e623813e79083f48f7654973d440fb0":[10,4,0,13],
+"group__pw__pipewire.html#ga4efeba27bea1dc8d9188b8e49b3bd1b0":[10,4,0,11],
+"group__pw__pipewire.html#ga52ada5751f37cb0e32ae79d20c1bf508":[10,4,0,10],
+"group__pw__pipewire.html#ga592c823ee1ec9f4be102f2dbe70f5aa5":[10,4,0,7],
+"group__pw__pipewire.html#ga61cbf71ec9b7c562cedb8a5a9ab04ceb":[10,4,0,4],
+"group__pw__pipewire.html#ga9b3cd1e03874212edf11b91bd1db9cda":[10,4,0,12],
+"group__pw__pipewire.html#gaab274e4e74769e7fab76ff7965740427":[10,4,0,15],
+"group__pw__pipewire.html#gacc287aaae982260a49eeac97f27a8227":[10,4,0,3],
+"group__pw__pipewire.html#gae7a5b43b7a86b9e79e9b3c3c549bdf65":[10,4,0,6],
+"group__pw__pipewire.html#gaf3d7686492ea5032eb135cddf21d3da2":[10,4,0,16],
+"group__pw__pipewire.html#gafa6045cd7391b467af4575c6752d6c4e":[10,4,0,2],
+"group__pw__pipewire.html#gafb27fefe2f3d0620f973c2c76ae3ba8b":[10,4,0,8],
+"group__pw__port.html":[10,4,12],
+"group__pw__port.html#ga08be9849ba07abfd630fcc2b9094e132":[10,4,12,5],
+"group__pw__port.html#ga0a2b3393a17045c7f8a6ff004c8c7f33":[10,4,12,22],
+"group__pw__port.html#ga0f310d02527226da27151627692f999b":[10,4,12,13],
+"group__pw__port.html#ga10cfbc658d844b76a5d3f3528cd2f345":[10,4,12,26],
+"group__pw__port.html#ga1ed9c2e11f128b205fa467a2c0f19fe1":[10,4,12,19],
 "group__pw__port.html#ga2d08d6e2358afc05ca212a0258fb6a26":[10,4,12,16],
 "group__pw__port.html#ga32a9f01e1dde49d9c5b6f64efe7af6e5":[10,4,12,6],
 "group__pw__port.html#ga3e912fde083fd69eca50d503c041eabb":[10,4,12,15],
@@ -218,36 +249,5 @@ var NAVTREEINDEX6 =
 "group__pw__session__manager.html#ga60daa7b99b0160772e5b5b8d5696fe54":[10,7,4,173],
 "group__pw__session__manager.html#ga61c63491758436617fc59af4f263b4eb":[10,7,4,62],
 "group__pw__session__manager.html#ga638a14bb21921dcaa09283a76a81f7a5":[10,7,4,145],
-"group__pw__session__manager.html#ga640eb23a56a0f38002b3f7d4ce5ce501":[10,7,4,48],
-"group__pw__session__manager.html#ga659e95476b1273ad6b2d247256375df7":[10,7,4,101],
-"group__pw__session__manager.html#ga6610bf9f3b9504539dfe55bd50588708":[10,7,4,57],
-"group__pw__session__manager.html#ga66409c7725bcc8631015483d84f731c9":[10,7,4,70],
-"group__pw__session__manager.html#ga666c22d90558b5ce7aeaee71537fafd5":[10,7,4,116],
-"group__pw__session__manager.html#ga6772def682a60b837c3234aa81e53c04":[10,7,4,46],
-"group__pw__session__manager.html#ga688c705fcfd1e1f2299c46bf9792d33b":[10,7,4,159],
-"group__pw__session__manager.html#ga68dc5bee3ea41a4168bf87bb537848cf":[10,7,4,151],
-"group__pw__session__manager.html#ga68e9035f497ceed218c7ab0a141706a2":[10,7,4,31],
-"group__pw__session__manager.html#ga6bac1a57bbfb7b6899ea70f9a49cbdd3":[10,7,4,117],
-"group__pw__session__manager.html#ga6c91bc3f4125db883c3ca7eefc0f0a5a":[10,7,4,172],
-"group__pw__session__manager.html#ga6c99759eac5533dee0959cb756cf988a":[10,7,4,143],
-"group__pw__session__manager.html#ga6cdfee6570f07ce60d6ee3cc22e730c3":[10,7,4,130],
-"group__pw__session__manager.html#ga6f364933a37b2abbb19f0a3fcc19b64f":[10,7,4,154],
-"group__pw__session__manager.html#ga6f46bdea51a973e31cada37277955aab":[10,7,4,100],
-"group__pw__session__manager.html#ga703c828d651cc8fdb939db06468c6956":[10,7,4,72],
-"group__pw__session__manager.html#ga748a0b2bb21288f7ad06e741598246a8":[10,7,4,114],
-"group__pw__session__manager.html#ga750ac9ec4fbc497f95536c95f4561ee6":[10,7,4,96],
-"group__pw__session__manager.html#ga771b101ee652676e0a596d74460a6354":[10,7,4,121],
-"group__pw__session__manager.html#ga7942053dc37f4422c4342845b98013ca":[10,7,4,110],
-"group__pw__session__manager.html#ga7bd339deb3e56304f3e0e84496d768ad":[10,7,4,102],
-"group__pw__session__manager.html#ga7d86a53322280ecfcc47734de89449fe":[10,7,4,79],
-"group__pw__session__manager.html#ga7dcaf114cea354db4a8f610ed968e2a7":[10,7,4,168],
-"group__pw__session__manager.html#ga7dfd0401a9b75ae042034c7c26dd3c2d":[10,7,4,176],
-"group__pw__session__manager.html#ga7e51bfdb707f25b2222dfae9c6dc7dea":[10,7,4,69],
-"group__pw__session__manager.html#ga80cfd20d3e9ae11495ec8086be5ffcd5":[10,7,4,169],
-"group__pw__session__manager.html#ga80f90aa35fb48a71f43dba9043a2455e":[10,7,4,178],
-"group__pw__session__manager.html#ga81bd4886f69e2d119c3fb59217bff171":[10,7,4,139],
-"group__pw__session__manager.html#ga81fbab389aafd05f10740275c1bc573a":[10,7,4,144],
-"group__pw__session__manager.html#ga881a2318b6234ad0869472a22141a906":[10,7,4,49],
-"group__pw__session__manager.html#ga8a2eaf7340c0b68ce278dd14d4cccbed":[10,7,4,53],
-"group__pw__session__manager.html#ga8b55930c438fa7f090ca2b03a9709c18":[10,7,4,60]
+"group__pw__session__manager.html#ga640eb23a56a0f38002b3f7d4ce5ce501":[10,7,4,48]
 };
